@@ -3,10 +3,11 @@
   Project: masudoku
   Platform: Fremantle (maemo5)
   Author: Petri Kultanen pete@petnetti.net
-  Last Edit: 15.2.2010
+  Last Edit: 3.6.2010
 */
 #include "sudokuselectnumberwidget.h"
 #include "sudokutable.h"
+#include "sudokusettings.h"
 #include <QPaintEvent>
 #include <QPainter>
 #include <QMouseEvent>
@@ -108,6 +109,12 @@ void SudokuSelectNumberWidget::paintEvent(QPaintEvent *aEvent)
     int h1=height1/4;
     int w1=width1/4;
     QPainter painter(this);
+    QColor gridColor = iSettings->getGridColor();
+    QColor fontColor = iSettings->getFontColor();
+    QColor fontColorWrong = iSettings->getWrongNumberFontColor();
+    QColor fontColorTableFull = iSettings->getFullGridColor();
+	QColor backgroundColor = iSettings->getBackgroundColor();
+
     for(int j=0;j<3;j++)
     {
         for(int i=0;i<3;i++)
@@ -116,14 +123,15 @@ void SudokuSelectNumberWidget::paintEvent(QPaintEvent *aEvent)
             painter.setFont(serifFont);
             int num = (j*3+i)+1;
             //If number won't fit in cell then draw it with black color.
-            if(iTable->isNumInAnyDirectionL(num,iX,iY) && num!=iTable->getNumL(iX,iY) && iSettingNumberHints && iNumberType==ENormalNumbers) painter.setPen(Qt::black);
-            else painter.setPen(Qt::white);
+            if(iTable->isNumInAnyDirectionL(num,iX,iY) && num!=iTable->getNumL(iX,iY) && iSettingNumberHints && iNumberType==ENormalNumbers) painter.setPen(fontColorWrong);
+            else painter.setPen(fontColor);
             painter.drawText(QRect(i*w1+(h1/4),j*h1,w1,h1),QString::number(num));
         }
     }
-    painter.setPen(Qt::white);
+    painter.setPen(fontColor);
     painter.drawText(QRect(0*w1+(h1/4),3*h1,w1*3,h1),"   Clear");
     //Draw outlines
+	painter.setPen(gridColor);
     for(int i=0;i<4;i++)
     {
         painter.drawLine(0,i*h1,width1-(w1),i*h1);
