@@ -3,13 +3,15 @@
   Project: masudoku
   Platform: Fremantle (maemo5)
   Author: Petri Kultanen pete@petnetti.net
-  Last Edit: 15.2.2010
+  Last Edit: 3.6.2010
 */
 #include "sudokutablewidget.h"
 #include "sudokutable.h"
+#include "sudokusettings.h"
 #include <QPaintEvent>
 #include <QPainter>
 #include <QMouseEvent>
+#include <QColor>
 SudokuTableWidget::SudokuTableWidget()
 {
     iSelectedX=0;
@@ -52,12 +54,21 @@ void  SudokuTableWidget::setSelectedCoordinates(int aX,int aY)
   */
 void SudokuTableWidget::paintEvent(QPaintEvent *aEvent)
 {
+
+	QColor gridColor = iSettings->getGridColor();
+	QColor fontColor = iSettings->getFontColor();
+	QColor fontColorWrong = iSettings->getWrongNumberFontColor();
+	QColor fontColorTableFull = iSettings->getFullGridColor();
+	QColor backgroundColor = iSettings->getBackgroundColor();
     int width1 = width();
     int height1 = height();
     int h1=height1/9;
-    int w1=width1/9;
+    int w1=width1/9;	
     QPainter painter(this);
-    painter.setPen(Qt::white);
+
+	//painter.draw
+    painter.setPen(gridColor);
+	
     for(int j=0;j<9;j++)
     {
         for(int i=0;i<9;i++)
@@ -69,71 +80,73 @@ void SudokuTableWidget::paintEvent(QPaintEvent *aEvent)
             }
             //set font
             QFont serifFont("Times",h1/2,QFont::Bold);
-            painter.setFont(serifFont);
+ 			painter.setFont(serifFont);           
             //Fill nnumbers, but leave zeros to blank.
+			painter.setPen(fontColor);
             if(iTable->getNumL(i,j)!=0)
             {
-                if(iTable->isNumInAnyDirectionL(iTable->getNumL(i,j),i,j)) painter.setPen(Qt::red);
+                if(iTable->isNumInAnyDirectionL(iTable->getNumL(i,j),i,j)) painter.setPen(fontColorWrong);
                 painter.drawText(QRect(i*w1+(h1/3),j*h1+(w1/6),w1,h1),QString::number(iTable->getNumL(i,j)));
-                painter.setPen(Qt::white);
-
+                painter.setPen(fontColor);
             }
             else //Draw mwmory numbers
-            {
+            {			
                 QFont serifFont("Times",h1/4,QFont::Bold);
                 painter.setFont(serifFont);
+				painter.setPen(fontColor);
                 //1
-                if(iTable->isNumInAnyDirectionL(1,i,j)) painter.setPen(Qt::red);
+                if(iTable->isNumInAnyDirectionL(1,i,j)) painter.setPen(fontColorWrong);
                 if(iTable->isMemoryNumber(1,i,j))
                     painter.drawText(QRect(i*w1+5,j*h1,w1/3,h1/3),QString::number(1));
-                painter.setPen(Qt::white);
+                painter.setPen(fontColor);
                 //2
-                if(iTable->isNumInAnyDirectionL(2,i,j)) painter.setPen(Qt::red);
+                if(iTable->isNumInAnyDirectionL(2,i,j)) painter.setPen(fontColorWrong);
                 if(iTable->isMemoryNumber(2,i,j))
                     painter.drawText(QRect(i*w1+15,j*h1,w1/3,h1/3),QString::number(2));
-                painter.setPen(Qt::white);
+                painter.setPen(fontColor);
                 //3
-                if(iTable->isNumInAnyDirectionL(3,i,j)) painter.setPen(Qt::red);
+                if(iTable->isNumInAnyDirectionL(3,i,j)) painter.setPen(fontColorWrong);
                 if(iTable->isMemoryNumber(3,i,j))
                     painter.drawText(QRect(i*w1+25,j*h1,w1/3,h1/3),QString::number(3));
-                painter.setPen(Qt::white);
+                painter.setPen(fontColor);
                 //4
-                if(iTable->isNumInAnyDirectionL(4,i,j)) painter.setPen(Qt::red);
+                if(iTable->isNumInAnyDirectionL(4,i,j)) painter.setPen(fontColorWrong);
                 if(iTable->isMemoryNumber(4,i,j))
                     painter.drawText(QRect(i*w1+5,j*h1+12,w1/3,h1/3),QString::number(4));
-                painter.setPen(Qt::white);
+                painter.setPen(fontColor);
                 //5
-                if(iTable->isNumInAnyDirectionL(5,i,j)) painter.setPen(Qt::red);
+                if(iTable->isNumInAnyDirectionL(5,i,j)) painter.setPen(fontColorWrong);
                 if(iTable->isMemoryNumber(5,i,j))
                     painter.drawText(QRect(i*w1+15,j*h1+12,w1/3,h1/3),QString::number(5));
-                painter.setPen(Qt::white);
+                painter.setPen(fontColor);
                 //6
-                if(iTable->isNumInAnyDirectionL(6,i,j)) painter.setPen(Qt::red);
+                if(iTable->isNumInAnyDirectionL(6,i,j)) painter.setPen(fontColorWrong);
                 if(iTable->isMemoryNumber(6,i,j))
                     painter.drawText(QRect(i*w1+25,j*h1+12,w1/3,h1/3),QString::number(6));
-                painter.setPen(Qt::white);
+                painter.setPen(fontColor);
                 //7
-                if(iTable->isNumInAnyDirectionL(7,i,j)) painter.setPen(Qt::red);
+                if(iTable->isNumInAnyDirectionL(7,i,j)) painter.setPen(fontColorWrong);
                 if(iTable->isMemoryNumber(7,i,j))
                     painter.drawText(QRect(i*w1+5,j*h1+25,w1/3,h1/3),QString::number(7));
-                painter.setPen(Qt::white);
+                painter.setPen(fontColor);
                 //8
-                if(iTable->isNumInAnyDirectionL(8,i,j)) painter.setPen(Qt::red);
+                if(iTable->isNumInAnyDirectionL(8,i,j)) painter.setPen(fontColorWrong);
                 if(iTable->isMemoryNumber(8,i,j))
                     painter.drawText(QRect(i*w1+15,j*h1+25,w1/3,h1/3),QString::number(8));
-                painter.setPen(Qt::white);
+                painter.setPen(fontColor);
                 //9
-                if(iTable->isNumInAnyDirectionL(9,i,j)) painter.setPen(Qt::red);
+                if(iTable->isNumInAnyDirectionL(9,i,j)) painter.setPen(fontColorWrong);
                 if(iTable->isMemoryNumber(9,i,j))
                     painter.drawText(QRect(i*w1+25,j*h1+25,w1/3,h1/3),QString::number(9));
-                painter.setPen(Qt::white);
+                painter.setPen(fontColor);
 
             }
 
         }
     }
     //Draw border lines
-    if(iTable->isTableFull() && !iTable->isErrorInTableL()) painter.setPen(Qt::green);
+	painter.setPen(gridColor);	
+    if(iTable->isTableFull() && !iTable->isErrorInTableL()) painter.setPen(fontColorTableFull);
     for(int i=0;i<10;i++)
     {
         painter.drawLine(0,i*h1,width1,i*h1);
